@@ -75,8 +75,97 @@
 
 #ifndef INCLUDED_volk_32f_sin_32f_a_H
 #define INCLUDED_volk_32f_sin_32f_a_H
+#ifdef LV_HAVE_AVX512F
 
+#include <immintrin.h>
+static inline void volk_32f_sin_32f_a_avx512f(float* sinVector,
+                                              const float* inVector,
+                                              unsigned int num_points)
+{
+    float* sinPtr = sinVector;
+    const float* inPtr = inVector;
 
+    unsigned int number = 0;
+    unsigned int sixteenPoints = num_points / 16;
+    unsigned int i = 0;
+
+    __m512 aVal, s, r, m4pi, pio4A, pio4B, pio4C, cp1, cp2, cp3, cp4, cp5, ffours, ftwos,
+        fones;
+    __m512 sine, cosine;
+    __m512i q, zeros, ones, twos, fours;
+
+    m4pi = _mm512_set1_ps(1.273239544735162542821171882678754627704620361328125);
+    pio4A = _mm512_set1_ps(0.7853981554508209228515625);
+    pio4B = _mm512_set1_ps(0.794662735614792836713604629039764404296875e-8);
+    pio4C = _mm512_set1_ps(0.306161699786838294306516483068750264552437361480769e-16);
+    ffours = _mm512_set1_ps(4.0);
+    ftwos = _mm512_set1_ps(2.0);
+    fones = _mm512_set1_ps(1.0);
+    zeros = _mm512_setzero_epi32();
+    ones = _mm512_set1_epi32(1);
+    twos = _mm512_set1_epi32(2);
+    fours = _mm512_set1_epi32(4);
+
+    cp1 = _mm512_set1_ps(1.0);
+    cp2 = _mm512_set1_ps(0.08333333333333333);
+    cp3 = _mm512_set1_ps(0.002777777777777778);
+    cp4 = _mm512_set1_ps(4.96031746031746e-05);
+    cp5 = _mm512_set1_ps(5.511463844797178e-07);
+    __mmask16 condition1, condition2, ltZero;
+
+    for (; number < sixteenPoints; number++) {
+        aVal = _mm512_load_ps(inPtr);
+        // s = fabs(aVal)
+        s = (__m512)(_mm512_and_si512((__m512i)(aVal), _mm512_set1_epi32(0x7fffffff)));
+
+        // q = (int) (s * (4/pi)), floor(aVal / (pi/4))
+        q = _mm512_cvtps_epi32(_mm512_floor_ps(_mm512_mul_ps(s, m4pi)));
+        // r = q + q&1, q indicates quadrant, r gives
+        r = _mm512_cvtepi32_ps(_mm512_add_epi32(q, _mm512_and_si512(q, ones)));
+
+        s = _mm512_fnmadd_ps(r, pio4A, s);
+        s = _mm512_fnmadd_ps(r, pio4B, s);
+        s = _mm512_fnmadd_ps(r, pio4C, s);
+
+        s = _mm512_div_ps(
+            s,
+            _mm512_set1_ps(8.0f)); // The constant is 2^N, for 3 times argument reduction
+        s = _mm512_mul_ps(s, s);
+        // Evaluate Taylor series
+        s = _mm512_mul_ps(
+            _mm512_fmadd_ps(
+                _mm512_fmsub_ps(
+                    _mm512_fmadd_ps(_mm512_fmsub_ps(s, cp5, cp4), s, cp3), s, cp2),
+                s,
+                cp1),
+            s);
+
+        for (i = 0; i < 3; i++)
+            s = _mm512_mul_ps(s, _mm512_sub_ps(ffours, s));
+        s = _mm512_div_ps(s, ftwos);
+
+        sine = _mm512_sqrt_ps(_mm512_mul_ps(_mm512_sub_ps(ftwos, s), s));
+        cosine = _mm512_sub_ps(fones, s);
+
+        condition1 = _mm512_cmpneq_epi32_mask(
+            _mm512_and_si512(_mm512_add_epi32(q, ones), twos), zeros);
+        ltZero = _mm512_cmp_ps_mask(aVal, _mm512_setzero_ps(), _CMP_LT_OS);
+        condition2 = _mm512_kxor(
+            _mm512_cmpneq_epi32_mask(_mm512_and_epi32(q, fours), zeros), ltZero);
+
+        sine = _mm512_mask_blend_ps(condition1, sine, cosine);
+        sine = _mm512_mask_mul_ps(sine, condition2, sine, _mm512_set1_ps(-1.f));
+        _mm512_store_ps(sinPtr, sine);
+        inPtr += 16;
+        sinPtr += 16;
+    }
+
+    number = sixteenPoints * 16;
+    for (; number < num_points; number++) {
+        *sinPtr++ = sinf(*inPtr++);
+    }
+}
+#endif
 #if LV_HAVE_AVX2 && LV_HAVE_FMA
 #include <immintrin.h>
 
@@ -379,6 +468,98 @@ volk_32f_sin_32f_a_sse4_1(float* bVector, const float* aVector, unsigned int num
 #ifndef INCLUDED_volk_32f_sin_32f_u_H
 #define INCLUDED_volk_32f_sin_32f_u_H
 
+#ifdef LV_HAVE_AVX512F
+
+#include <immintrin.h>
+static inline void volk_32f_sin_32f_u_avx512f(float* sinVector,
+                                              const float* inVector,
+                                              unsigned int num_points)
+{
+    float* sinPtr = sinVector;
+    const float* inPtr = inVector;
+
+    unsigned int number = 0;
+    unsigned int sixteenPoints = num_points / 16;
+    unsigned int i = 0;
+
+    __m512 aVal, s, r, m4pi, pio4A, pio4B, pio4C, cp1, cp2, cp3, cp4, cp5, ffours, ftwos,
+        fones;
+    __m512 sine, cosine;
+    __m512i q, zeros, ones, twos, fours;
+
+    m4pi = _mm512_set1_ps(1.273239544735162542821171882678754627704620361328125);
+    pio4A = _mm512_set1_ps(0.7853981554508209228515625);
+    pio4B = _mm512_set1_ps(0.794662735614792836713604629039764404296875e-8);
+    pio4C = _mm512_set1_ps(0.306161699786838294306516483068750264552437361480769e-16);
+    ffours = _mm512_set1_ps(4.0);
+    ftwos = _mm512_set1_ps(2.0);
+    fones = _mm512_set1_ps(1.0);
+    zeros = _mm512_setzero_epi32();
+    ones = _mm512_set1_epi32(1);
+    twos = _mm512_set1_epi32(2);
+    fours = _mm512_set1_epi32(4);
+
+    cp1 = _mm512_set1_ps(1.0);
+    cp2 = _mm512_set1_ps(0.08333333333333333);
+    cp3 = _mm512_set1_ps(0.002777777777777778);
+    cp4 = _mm512_set1_ps(4.96031746031746e-05);
+    cp5 = _mm512_set1_ps(5.511463844797178e-07);
+    __mmask16 condition1, condition2, ltZero;
+
+    for (; number < sixteenPoints; number++) {
+        aVal = _mm512_loadu_ps(inPtr);
+        // s = fabs(aVal)
+        s = (__m512)(_mm512_and_si512((__m512i)(aVal), _mm512_set1_epi32(0x7fffffff)));
+
+        // q = (int) (s * (4/pi)), floor(aVal / (pi/4))
+        q = _mm512_cvtps_epi32(_mm512_floor_ps(_mm512_mul_ps(s, m4pi)));
+        // r = q + q&1, q indicates quadrant, r gives
+        r = _mm512_cvtepi32_ps(_mm512_add_epi32(q, _mm512_and_si512(q, ones)));
+
+        s = _mm512_fnmadd_ps(r, pio4A, s);
+        s = _mm512_fnmadd_ps(r, pio4B, s);
+        s = _mm512_fnmadd_ps(r, pio4C, s);
+
+        s = _mm512_div_ps(
+            s,
+            _mm512_set1_ps(8.0f)); // The constant is 2^N, for 3 times argument reduction
+        s = _mm512_mul_ps(s, s);
+        // Evaluate Taylor series
+        s = _mm512_mul_ps(
+            _mm512_fmadd_ps(
+                _mm512_fmsub_ps(
+                    _mm512_fmadd_ps(_mm512_fmsub_ps(s, cp5, cp4), s, cp3), s, cp2),
+                s,
+                cp1),
+            s);
+
+        for (i = 0; i < 3; i++)
+            s = _mm512_mul_ps(s, _mm512_sub_ps(ffours, s));
+        s = _mm512_div_ps(s, ftwos);
+
+        sine = _mm512_sqrt_ps(_mm512_mul_ps(_mm512_sub_ps(ftwos, s), s));
+        cosine = _mm512_sub_ps(fones, s);
+
+        condition1 = _mm512_cmpneq_epi32_mask(
+            _mm512_and_si512(_mm512_add_epi32(q, ones), twos), zeros);
+        ltZero = _mm512_cmp_ps_mask(aVal, _mm512_setzero_ps(), _CMP_LT_OS);
+        condition2 = _mm512_kxor(
+            _mm512_cmpneq_epi32_mask(_mm512_and_epi32(q, fours), zeros), ltZero);
+
+        sine = _mm512_mask_blend_ps(condition1, sine, cosine);
+        sine = _mm512_mask_mul_ps(sine, condition2, sine, _mm512_set1_ps(-1.f));
+        _mm512_storeu_ps(sinPtr, sine);
+        inPtr += 16;
+        sinPtr += 16;
+    }
+
+    number = sixteenPoints * 16;
+    for (; number < num_points; number++) {
+        *sinPtr++ = sinf(*inPtr++);
+    }
+}
+#endif
+
 #if LV_HAVE_AVX2 && LV_HAVE_FMA
 #include <immintrin.h>
 
